@@ -4,6 +4,7 @@ import logging
 import orjson
 import typing
 
+from pathlib import Path
 from starlette.websockets import WebSocket
 from starlette.endpoints import WebSocketEndpoint
 
@@ -164,3 +165,10 @@ class WebSocketRouter:
         """
         return self._epClass(*arg, routes=self.routes, **kw)
 
+    @property
+    def jspath(self):
+        """
+        Return the JavaScript path for use with Starlette Mount commands
+        """
+        return Path(__file__).parent/'static'
+
